# Model Feature Scan Report

_Report generated on: 2025-06-10T23:33:45.234542_

## API: OpenAIApi

### API Summary

* **Total Models Scanned:** 31
* **Average Supported Features per Model:** 2.58

#### Feature Support Across Models:

* Audio: 0.0% (0/31)
* AudioConversion: 0.0% (0/31)
* AudioEmbeddings: 3.2% (1/31)
* AudioGeneration: 3.2% (1/31)
* AudioTranscription: 3.2% (1/31)
* Document: 35.5% (11/31)
* DocumentConversion: 0.0% (0/31)
* DocumentEmbeddings: 3.2% (1/31)
* Image: 38.7% (12/31)
* ImageConversion: 0.0% (0/31)
* ImageEmbeddings: 3.2% (1/31)
* ImageGeneration: 3.2% (1/31)
* StructuredTextGeneration: 48.4% (15/31)
* TextEmbeddings: 3.2% (1/31)
* TextGeneration: 48.4% (15/31)
* Thinking: 41.9% (13/31)
* Tools: 0.0% (0/31)
* Video: 19.4% (6/31)
* VideoConversion: 0.0% (0/31)
* VideoEmbeddings: 3.2% (1/31)
* VideoGeneration: 0.0% (0/31)
* WebSearchTool: 0.0% (0/31)

### Model Details

#### Model: chatgpt-4o-latest (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: fastembed (5/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ✅ ImageEmbeddings
* ✅ AudioEmbeddings
* ✅ VideoEmbeddings
* ✅ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1 (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1-mini (3/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1-nano (3/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o (3/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-audio-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini (3/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-audio-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-realtime-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-search-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-transcribe (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-tts (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ✅ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-realtime-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-search-preview (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-transcribe (0/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-image-1 (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ✅ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-high (6/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-low (6/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-medium (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-high (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-low (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-medium (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-preview (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-high (6/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-low (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-medium (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-high (4/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-low (4/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-medium (5/22 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ✅ Video
* ✅ Document
* ❌ Tools
* ❌ WebSearchTool
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: whisper-local (1/22 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ WebSearchTool
* ✅ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API
restrictions, or potential bugs in Litemind._